@@ -80,6 +80,7 @@ import net.sf.jftp.gui.framework.GUIDefaults;
 import net.sf.jftp.gui.framework.HDesktopBackground;
 import net.sf.jftp.gui.framework.HImage;
 import net.sf.jftp.gui.hostchooser.HostChooser;
+import net.sf.jftp.gui.hostchooser.SftpHostChooser;
 import net.sf.jftp.gui.tasks.HostInfo;
 import net.sf.jftp.net.BasicConnection;
 import net.sf.jftp.net.ConnectionHandler;
@@ -493,7 +494,11 @@ public class JFtp extends JPanel implements WindowListener, ComponentListener,
         remoteDir.actionPerformed(this, "remote");
         desktop.remove(background);
         addBackgroundImage();
+             
         validate();
+        
+        System.out.println(statusP.status);
+        statusP.status.fresh();
     }
 
     public void addBackgroundImage()
@@ -649,30 +654,30 @@ public class JFtp extends JPanel implements WindowListener, ComponentListener,
     			}
     		}
 
-    		/*
-                try
-                {
-                    Class.forName("com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
-                    UIManager.installLookAndFeel("PlasticXP",
-                                                 "com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
+/*
+    		try
+    		{
+    			Class.forName("com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
+    			UIManager.installLookAndFeel("PlasticXP",
+    			"com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
 
-                    Class.forName("com.jgoodies.looks.plastic.Plastic3DLookAndFeel");
-                    UIManager.installLookAndFeel("Plastic3D",
-                                                 "com.jgoodies.looks.plastic.Plastic3DLookAndFeel");
+    			Class.forName("com.jgoodies.looks.plastic.Plastic3DLookAndFeel");
+    			UIManager.installLookAndFeel("Plastic3D",
+    			"com.jgoodies.looks.plastic.Plastic3DLookAndFeel");
 
-                    Class.forName("com.jgoodies.looks.plastic.PlasticLookAndFeel");
-                    UIManager.installLookAndFeel("Plastic",
-                                                 "com.jgoodies.looks.plastic.PlasticLookAndFeel");
+    			Class.forName("com.jgoodies.looks.plastic.PlasticLookAndFeel");
+    			UIManager.installLookAndFeel("Plastic",
+    			"com.jgoodies.looks.plastic.PlasticLookAndFeel");
 
-                    Class.forName("com.jgoodies.looks.windows.WindowsLookAndFeel");
-                    UIManager.installLookAndFeel("Windows",
-                                                 "com.jgoodies.looks.windows.WindowsLookAndFeel");
-                }
-                catch(ClassNotFoundException cnfe)
-                {
-                    ex.printStackTrace();
-                }
-    		 */
+    			Class.forName("com.jgoodies.looks.windows.WindowsLookAndFeel");
+    			UIManager.installLookAndFeel("Windows",
+    			"com.jgoodies.looks.windows.WindowsLookAndFeel");
+    		}
+    		catch(ClassNotFoundException cnfe)
+    		{
+    			cnfe.printStackTrace();
+    		}
+*/
     		mainFrame = new JFrame();
     		mainFrame.setLocation(Settings.getWindowLocation());
 
@@ -700,7 +705,12 @@ public class JFtp extends JPanel implements WindowListener, ComponentListener,
 
     		if(argv.length > 0)
     		{
-    			jftp.hc.update(argv[0]);
+    			if(argv[0].indexOf("sftp:") >= 0) {
+    				new SftpHostChooser().update(argv[0].replaceAll("sftp:", "ftp:"));
+    			}
+    			else {
+    				jftp.hc.update(argv[0]);
+    			}
     		}
     		else
     		{
