@@ -27,11 +27,16 @@ public class ProgressbarItem extends JPanel {
 		setSize(300,25);
 	}
 	
-	public void update(int size, int max, String lbl) {
+	public void update(long size, long max, String lbl) {
 
+		while(max > Integer.MAX_VALUE) {
+			max = max / 1000;
+			size = size / 1000;
+		}
+		
 		if(max > 0) {
-			bar.setMaximum(max);
-			bar.setValue(size);
+			bar.setMaximum((int) max);
+			bar.setValue((int) size);
 		}
 		else {
 			bar.setMaximum(99999999);
