@@ -29,6 +29,7 @@ import java.awt.event.WindowEvent;
 import java.awt.event.WindowListener;
 import java.io.IOException;
 
+import javax.swing.BoxLayout;
 import javax.swing.JCheckBox;
 import javax.swing.JDialog;
 import javax.swing.JLabel;
@@ -42,6 +43,7 @@ import net.sf.jftp.config.Settings;
 import net.sf.jftp.gui.base.FtpHost;
 import net.sf.jftp.gui.framework.HButton;
 import net.sf.jftp.gui.framework.HFrame;
+import net.sf.jftp.gui.framework.HInsetPanel;
 import net.sf.jftp.gui.framework.HPanel;
 import net.sf.jftp.gui.framework.HPasswordField;
 import net.sf.jftp.gui.framework.HTextField;
@@ -49,7 +51,7 @@ import net.sf.jftp.gui.tasks.HostList;
 import net.sf.jftp.net.FilesystemConnection;
 import net.sf.jftp.net.FtpConnection;
 import net.sf.jftp.net.FtpURLConnection;
-import net.sf.jftp.net.StartConnection;
+import net.sf.jftp.net.wrappers.StartConnection;
 import net.sf.jftp.system.StringUtils;
 import net.sf.jftp.system.logging.Log;
 
@@ -109,11 +111,8 @@ public class HostChooser extends HFrame implements ActionListener,
 
     public void init()
     {
-        //setSize(600, 340);
-       // setLocation(50, 150);
         setTitle("Ftp Connection...");
         setBackground(okP.getBackground());
-        getContentPane().setLayout(new GridLayout((ext ? 8 : 7), 2, 5, 3));
 
         anonBox.setSelected(false);
         user.setEnabled(true);
@@ -155,32 +154,34 @@ public class HostChooser extends HFrame implements ActionListener,
             pass.setText("");
         }
 
-        getContentPane().add(host);
-        getContentPane().add(port);
-        getContentPane().add(anonBox);
-        getContentPane().add(listBox);
-        getContentPane().add(user);
-        getContentPane().add(pass);
-        getContentPane().add(dirBox);
-        getContentPane().add(modeBox);
-        getContentPane().add(lcwd);
-        getContentPane().add(cwd);
-        getContentPane().add(threadBox);
-        getContentPane().add(dl);
+        HInsetPanel root = new HInsetPanel();
+        root.setLayout(new GridLayout((ext ? 8 : 7), 2, 5, 3));
+        root.add(host);
+        root.add(port);
+        root.add(anonBox);
+        root.add(listBox);
+        root.add(user);
+        root.add(pass);
+        root.add(dirBox);
+        root.add(modeBox);
+        root.add(lcwd);
+        root.add(cwd);
+        root.add(threadBox);
+        root.add(dl);
 
-if(ext) {
-        getContentPane().add(crlf);
+        if(ext) {
+        	root.add(crlf);
 
-	JPanel x1 = new JPanel();
-	x1.setLayout(new BorderLayout(2,2));
-	JLabel l1 = new JLabel("Unix: LF, Mac/MVS: CR, Win: CRLF");
-	l1.setFont(new Font("Dialog", Font.PLAIN, 10));
-	JLabel l2 = new JLabel("Don't change this unless you transfer text only");
-	l2.setFont(new Font("Dialog", Font.PLAIN, 10));
-	x1.add("North", l1);
-	x1.add("South", l2);
-        getContentPane().add(x1);
-}
+        	JPanel x1 = new JPanel();
+        	x1.setLayout(new BorderLayout(2,2));
+        	JLabel l1 = new JLabel("Unix: LF, Mac/MVS: CR, Win: CRLF");
+        	l1.setFont(new Font("Dialog", Font.PLAIN, 10));
+        	JLabel l2 = new JLabel("Don't change this unless you transfer text only");
+        	l2.setFont(new Font("Dialog", Font.PLAIN, 10));
+        	x1.add("North", l1);
+        	x1.add("South", l2);
+        	root.add(x1);
+        }
 
         modeBox.setSelected(!Settings.getFtpPasvMode());
         threadBox.setSelected(Settings.getEnableMultiThreading());
@@ -188,11 +189,11 @@ if(ext) {
         anonBox.addActionListener(this);
         threadBox.addActionListener(this);
 
-        getContentPane().add(okP);
+        root.add(okP);
         okP.add(ok);
         ok.addActionListener(this);
 
-        getContentPane().add(listP);
+        root.add(listP);
         listP.add(list);
         list.addActionListener(this);
 
@@ -203,21 +204,24 @@ if(ext) {
         cwd.setEnabled(!dirBox.isSelected());
         pass.text.addActionListener(this);
 
+        getContentPane().setLayout(new BorderLayout(10,10));
+        getContentPane().add("Center", root);
+        
         pack();
         setModal(false);
         setVisible(false);
-        invalidate();
-        validate();
+        //invalidate();
+        //validate();
         addWindowListener(this);
         prepareBackgroundMessage();
     }
 
     public void update()
     {
-	fixLocation();
-        setVisible(true);
-        toFront();
-        host.requestFocus();
+    	fixLocation();
+    	setVisible(true);
+    	toFront();
+    	host.requestFocus();
     }
 
     public void update(String url)
@@ -548,15 +552,7 @@ if(ext) {
     public void windowOpened(WindowEvent e)
     {
     }
-
-    public Insets getInsets()
-    {
-        Insets std = super.getInsets();
-
-        return new Insets(std.top + 10, std.left + 10, std.bottom + 10,
-                          std.right + 10);
-    }
-
+    
     public void pause(int time)
     {
         try
@@ -611,14 +607,6 @@ if(ext) {
 
                 System.out.println("0...");
 
-                /* con = new
-                        FtpConnection(
-                                htmp,
-                                Integer.parseInt(potmp),
-                                dtmp);
-
-                */
-                //response = con.login(utmp, ptmp);
                 response = StartConnection.startFtpCon(htmp, utmp, ptmp,
                                                        Integer.parseInt(potmp),
                                                        dtmp, useLocal);
@@ -660,5 +648,4 @@ if(ext) {
         }
     }
 
-    //*** tryFtpAgain
 }
