@@ -15,18 +15,18 @@
  */
 package net.sf.jftp.net;
 
-
-//***now all config files are imported
 import java.io.BufferedReader;
-import java.io.DataInputStream;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.InputStreamReader;
 import java.io.OutputStream;
 import java.net.InetAddress;
 import java.net.ServerSocket;
 import java.net.UnknownHostException;
+import java.util.Calendar;
 import java.util.Date;
+import java.util.GregorianCalendar;
 import java.util.StringTokenizer;
 import java.util.Vector;
 
@@ -116,7 +116,7 @@ public class FtpConnection implements BasicConnection, FtpConstants
     private FtpTransfer lastTransfer = null;
     private boolean modeStreamSet = false;
     private DataConnection dcon = null;
-    private Vector listeners = new Vector();
+    private Vector<ConnectionListener> listeners = new Vector<ConnectionListener>();
     private ConnectionHandler handler = new ConnectionHandler();
 
     // directory downloaded to
@@ -152,11 +152,11 @@ public class FtpConnection implements BasicConnection, FtpConstants
     /**
     * May contain date listing
     */
-    public Vector dateVector = new Vector();
-    public Vector currentListing = new Vector();
-    public Vector currentFiles = new Vector();
-    public Vector currentSizes = new Vector();
-    public Vector currentPerms = new Vector();
+    public Vector<Date> dateVector = new Vector<Date>();
+    public Vector<String> currentListing = new Vector<String>();
+    public Vector<String> currentFiles = new Vector<String>();
+    public Vector<String> currentSizes = new Vector<String>();
+    public Vector<String> currentPerms = new Vector<String>();
 
     /**
     * Create an instance with a given host
@@ -335,7 +335,7 @@ public class FtpConnection implements BasicConnection, FtpConstants
                 {
                     LIST = LIST_DEFAULT;
 
-                    SaveSet s = new SaveSet(Settings.adv_settings, LIST);
+                    new SaveSet(Settings.adv_settings, LIST);
                 }
                 else
                 {
@@ -483,7 +483,7 @@ public class FtpConnection implements BasicConnection, FtpConstants
         return toArray(currentSizes);
     }
 
-    private String[] toArray(Vector in) {
+    private String[] toArray(Vector<String> in) {
         String ret[] = new String[in.size()];
         
         for(int i=0; i<in.size(); i++) {
@@ -628,7 +628,7 @@ public class FtpConnection implements BasicConnection, FtpConstants
         try
         {
         	boolean newUnixDateStyle = false;
-            dateVector = new Vector();
+            dateVector = new Vector<Date>();
             currentFiles.removeAllElements();
         	
             for(int i=0; i<currentListing.size(); i++)
@@ -846,14 +846,14 @@ public class FtpConnection implements BasicConnection, FtpConstants
                                                      date2.indexOf(":") + 3);
 
                         //Log.out("day:"+day+"year:"+y+"mon:"+m+"hour:"+h+"m:"+min);
-                        Date d = new Date();
-                        d.setDate(Integer.parseInt(day));
-                        d.setYear(Integer.parseInt(y));
-                        d.setMonth(Integer.parseInt(m) - 1);
-                        d.setHours(Integer.parseInt(h));
-                        d.setMinutes(Integer.parseInt(min));
+                        Calendar c = new GregorianCalendar();
+                        c.set(Calendar.DAY_OF_MONTH, Integer.parseInt(day));
+                        c.set(Calendar.YEAR, Integer.parseInt(y));
+                        c.set(Calendar.MONTH, Integer.parseInt(m) - 1);
+                        c.set(Calendar.HOUR, Integer.parseInt(h));
+                        c.set(Calendar.MINUTE, Integer.parseInt(min));
 
-                        dateVector.add(d);
+                        dateVector.add(c.getTime());
 
                         //Log.out("+++ date: \"" + d.toString() + "\"");
                     }
@@ -869,7 +869,7 @@ public class FtpConnection implements BasicConnection, FtpConstants
 
                     if(lcount > 1)
                     {
-                        dateVector = new Vector();
+                        dateVector = new Vector<Date>();
                     }
                 }
                 else if(tokens > 8) // unix
@@ -959,7 +959,6 @@ public class FtpConnection implements BasicConnection, FtpConstants
     /** get a filename */
     private String giveFile(StringTokenizer to, int lev)
     {
-        String t2 = null;
 
         for(int i = 0; i < lev; i++)
         {
@@ -1262,7 +1261,7 @@ public class FtpConnection implements BasicConnection, FtpConstants
 
             String path = getLocalPath() + file;
 
-            BufferedReader in = jcon.getReader();
+            //BufferedReader in = jcon.getReader();
 
             modeStream();
             p = negotiatePort();
@@ -1807,7 +1806,7 @@ public class FtpConnection implements BasicConnection, FtpConstants
         }
 
         String single = StringUtils.getDir(dir);
-        String path = dir.substring(0, dir.indexOf(single));
+        //String path = dir.substring(0, dir.indexOf(single));
 
         String remoteDir = getCachedPWD() + single; //StringUtils.removeStart(dir,path);
         String oldDir = getCachedPWD();
@@ -2308,7 +2307,7 @@ public class FtpConnection implements BasicConnection, FtpConstants
 
         try
         {
-            BufferedReader in = jcon.getReader();
+            //BufferedReader in = jcon.getReader();
 
             int p = 0;
 
@@ -2325,11 +2324,10 @@ public class FtpConnection implements BasicConnection, FtpConstants
             	//System.out.print("#");
                 pause(10);
             }
-            DataInputStream input = new DataInputStream(dcon.getInputStream());
+            BufferedReader input = new BufferedReader(new InputStreamReader(dcon.getInputStream()));
             
             jcon.send(LIST);
-
-            
+           
             String line;
             currentListing.removeAllElements();
             
@@ -2371,7 +2369,7 @@ public class FtpConnection implements BasicConnection, FtpConstants
     public boolean chdir(String p)
     {
 	//Log.out("Change directory to: "+p);
-	String tmpPath = p;
+	//String tmpPath = p;
 
         boolean tmp = chdirWork(p);
 
@@ -2424,7 +2422,7 @@ public class FtpConnection implements BasicConnection, FtpConstants
 	     }
 	     //TODO let dirlister form correct syntax
 
-             p = p.replaceAll("/", "");
+         p = p.replaceAll("/", "");
 	     boolean ew = p.startsWith("'");
 	     String tmp = null;
 
@@ -2678,10 +2676,12 @@ public class FtpConnection implements BasicConnection, FtpConstants
         return portb;
     }
 
+    /*
     private void incrementPort()
     {
         portb++;
     }
+    */
 
     /*
     private String getActivePortCmd() throws UnknownHostException, IOException
@@ -2944,7 +2944,7 @@ public class FtpConnection implements BasicConnection, FtpConstants
     *
     * @param l A Vector containig ConnectionListener objects
     */
-    public void setConnectionListeners(Vector l)
+    public void setConnectionListeners(Vector<ConnectionListener> l)
     {
         listeners = l;
     }
